@@ -22,7 +22,6 @@ using abigail::ir::environment_sptr;
 using abigail::comparison::corpus_diff_sptr;
 using abigail::comparison::compute_diff;
 using abigail::comparison::print_diff_tree;
-using abigail::comparison::apply_filters;
 using namespace abigail;
 
 struct options
@@ -104,7 +103,7 @@ main(int argc, char* argv[])
       corpus_sptr c1, c2;
 
       environment env;
-      vector<char**> di_roots;
+      vector<string> di_roots;
       c1 = dwarf::read_corpus_from_elf(opts.elf1, di_roots, env,
 				       /*load_all_types=*/false,
 				       c1_status);
@@ -131,11 +130,8 @@ main(int argc, char* argv[])
 	  return 1;
 	}
 
-      if (opts.categorize_redundancy)
-	categorize_redundancy(diff);
-
-      if (opts.apply_filters)
-	apply_filters(diff);
+      if (opts.categorize_redundancy || opts.apply_filters)
+	apply_filters_and_categorize_diff_node_tree(diff);
 
       print_diff_tree(diff, cout);
       return 0;
