@@ -160,7 +160,7 @@ main(int argc, char **argv)
   abigail::ir::environment env;
   abigail::corpus_sptr c;
   abigail::fe_iface::status status = abigail::fe_iface::STATUS_OK;
-  std::vector<char**> di_roots;
+  std::vector<string> di_roots;
   if (!(c = dwarf::read_corpus_from_elf(file_name, di_roots, env,
 					/*load_all_type=*/false,
 					status)))
