@@ -81,12 +81,12 @@ using abigail::comparison::corpus_diff;
 using abigail::comparison::corpus_diff_sptr;
 using abigail::comparison::function_type_diff_sptr;
 using abigail::comparison::compute_diff;
+using abigail::comparison::get_default_harmless_categories_bitmap;
+using abigail::comparison::apply_filters_and_categorize_diff_node_tree;
 using abigail::suppr::suppression_sptr;
 using abigail::suppr::suppressions_type;
 using abigail::suppr::read_suppressions;
 
-
-
 class options
 {
   options();
@@ -97,9 +97,9 @@ public:
   string		app_path;
   string		lib1_path;
   string		lib2_path;
-  shared_ptr<char>	app_di_root_path;
-  shared_ptr<char>	lib1_di_root_path;
-  shared_ptr<char>	lib2_di_root_path;
+  string		app_di_root_path;
+  string		lib1_di_root_path;
+  string		lib2_di_root_path;
   vector<string>	suppression_paths;
   bool			display_help;
   bool			display_version;
@@ -295,7 +295,7 @@ parse_command_line(int argc, char* argv[], options& opts)
 	  // elfutils wants the root path to the debug info to be
 	  // absolute.
 	  opts.app_di_root_path =
-	    abigail::tools_utils::make_path_absolute(argv[i + 1]);
+	    abigail::tools_utils::make_path_absolute(string(argv[i + 1]));
 	  ++i;
 	}
       else if (!strcmp(argv[i], "--lib-debug-info-dir1")
@@ -307,7 +307,7 @@ parse_command_line(int argc, char* argv[], options& opts)
 	  // elfutils wants the root path to the debug info to be
 	  // absolute.
 	  opts.lib1_di_root_path =
-	    abigail::tools_utils::make_path_absolute(argv[i + 1]);
+	    abigail::tools_utils::make_path_absolute(string(argv[i + 1]));
 	  ++i;
 	}
       else if (!strcmp(argv[i], "--lib-debug-info-dir2")
@@ -319,7 +319,7 @@ parse_command_line(int argc, char* argv[], options& opts)
 	  // elfutils wants the root path to the debug info to be
 	  // absolute.
 	  opts.lib2_di_root_path =
-	    abigail::tools_utils::make_path_absolute(argv[i + 1]);
+	    abigail::tools_utils::make_path_absolute(string(argv[i + 1]));
 	  ++i;
 	}
       else if (!strcmp(argv[i], "--suppressions")
@@ -402,14 +402,7 @@ create_diff_context(const options& opts)
   ctxt->show_locs(opts.show_locs);
   // Intentional logic flip of ignore_soname
   ctxt->show_soname_change(!opts.ignore_soname);
-  ctxt->switch_categories_off
-    (abigail::comparison::ACCESS_CHANGE_CATEGORY
-     | abigail::comparison::COMPATIBLE_TYPE_CHANGE_CATEGORY
-     | abigail::comparison::HARMLESS_DECL_NAME_CHANGE_CATEGORY
-     | abigail::comparison::NON_VIRT_MEM_FUN_CHANGE_CATEGORY
-     | abigail::comparison::STATIC_DATA_MEMBER_CHANGE_CATEGORY
-     | abigail::comparison::HARMLESS_ENUM_CHANGE_CATEGORY
-     | abigail::comparison::HARMLESS_SYMBOL_ALIAS_CHANGE_CATEGORY);
+  ctxt->switch_categories_off(get_default_harmless_categories_bitmap());
 
   // Load suppression specifications, if there are any.
   suppressions_type supprs;
@@ -483,6 +476,8 @@ compare_expected_against_provided_functions(diff_context_sptr&		ctxt,
 		compute_diff(expected_fn->get_type(),
 			     exported_fn->get_type(),
 			     ctxt);
+	      diff_sptr diff_tree = is_diff(fn_type_diff);
+	      apply_filters_and_categorize_diff_node_tree(diff_tree);
 	      if (fn_type_diff && fn_type_diff->to_be_reported())
 		{
 		  // So there is a type change between the function
@@ -557,6 +552,7 @@ compare_expected_against_provided_variables(diff_context_sptr&		ctxt,
 		compute_diff(expected_var->get_type(),
 			     exported_var->get_type(),
 			     ctxt);
+	      apply_filters_and_categorize_diff_node_tree(type_diff);
 	      if (type_diff && type_diff->to_be_reported())
 		{
 		  // So there is a type change between the variable
@@ -849,7 +845,7 @@ perform_compat_check_in_weak_mode(options& opts,
 static corpus_sptr
 read_corpus(options			opts,
 	    abigail::fe_iface::status&	status,
-	    const vector<char**>	di_roots,
+	    const vector<string>	di_roots,
 	    environment		&env,
 	    const string		&path)
 {
@@ -911,6 +907,8 @@ main(int argc, char* argv[])
 {
   options opts(argv[0]);
 
+  abigail::tools_utils::initialize();
+
   if (!parse_command_line(argc, argv, opts))
     {
       if (!opts.unknow_option.empty())
@@ -980,9 +978,10 @@ main(int argc, char* argv[])
     return abigail::tools_utils::ABIDIFF_OK;
 
   // Read the application ELF file.
-  char * app_di_root = opts.app_di_root_path.get();
-  vector<char**> app_di_roots;
-  app_di_roots.push_back(&app_di_root);
+  string& app_di_root = opts.app_di_root_path;
+  vector<string> app_di_roots;
+  if (!app_di_root.empty())
+    app_di_roots.push_back(app_di_root);
   abigail::fe_iface::status status = abigail::fe_iface::STATUS_UNKNOWN;
   environment env;
 
@@ -1040,9 +1039,10 @@ main(int argc, char* argv[])
   if (!abigail::tools_utils::check_file(opts.lib1_path, cerr, opts.prog_name))
     return abigail::tools_utils::ABIDIFF_ERROR;
 
-  char * lib1_di_root = opts.lib1_di_root_path.get();
-  vector<char**> lib1_di_roots;
-  lib1_di_roots.push_back(&lib1_di_root);
+  string& lib1_di_root = opts.lib1_di_root_path;
+  vector<string> lib1_di_roots;
+  if (!lib1_di_root.empty())
+    lib1_di_roots.push_back(lib1_di_root);
   corpus_sptr lib1_corpus = read_corpus(opts, status,
 					lib1_di_roots,
 					env, opts.lib1_path);
@@ -1075,9 +1075,10 @@ main(int argc, char* argv[])
   if (!opts.weak_mode)
     {
       ABG_ASSERT(!opts.lib2_path.empty());
-      char * lib2_di_root = opts.lib2_di_root_path.get();
-      vector<char**> lib2_di_roots;
-      lib2_di_roots.push_back(&lib2_di_root);
+      string& lib2_di_root = opts.lib2_di_root_path;
+      vector<string> lib2_di_roots;
+      if (!lib2_di_root.empty())
+	lib2_di_roots.push_back(lib2_di_root);
       lib2_corpus = read_corpus(opts, status,
 				lib2_di_roots, env,
 				opts.lib2_path);
